#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_ADXL345_U.h>
#include <Keyboard.h>  // 引入 Keyboard 函式庫

Adafruit_ADXL345_Unified accel = Adafruit_ADXL345_Unified(12345);

int shakeCount = 0;        // 揮動次數計數器
int shakeThreshold = 40;   // 調低加速度閾值，增加靈敏度
const int ledPin = 13;     // 燈接腳

// 上一次揮動的時間
unsigned long lastShakeTime = 0;
unsigned long debounceDelay = 1000;  // 增加揮動之間的延遲，單位為毫秒

void setup() {
  Serial.begin(9600);
  if (!accel.begin()) {
    Serial.println("ADXL345 not detected");
    while (1);
  }
  accel.setRange(ADXL345_RANGE_16_G);
  pinMode(ledPin, OUTPUT);

  Keyboard.begin();  // 初始化 Keyboard 函式庫
}

void loop() {
  sensors_event_t event;
  accel.getEvent(&event);

  // 當前時間
  unsigned long currentTime = millis();

  // 檢測X或Y軸是否達到閾值，並且檢查是否超過延遲時間
  if ((abs(event.acceleration.x) > shakeThreshold || abs(event.acceleration.y) > shakeThreshold) && 
      (currentTime - lastShakeTime > debounceDelay)) {
      
    shakeCount++;  // 增加揮動次數
    Serial.print("Shake Count: ");
    Serial.println(shakeCount);  // 在序列監控視窗中顯示揮動次數

    digitalWrite(ledPin, HIGH);  // 燈亮起
    delay(1000);  // 燈保持亮1秒（可自行調整）
    
    // 模擬按下右鍵鍵盤按鍵
    Keyboard.press(KEY_RIGHT_ARROW);
    delay(100);  // 按住鍵100毫秒
    Keyboard.releaseAll();  // 釋放所有按鍵
    
    digitalWrite(ledPin, LOW);   // 燈熄滅
    lastShakeTime = currentTime; // 更新最後揮動時間
  }
  
  delay(100);  // 減少讀取頻率，防止過敏感
}



